@@ -35,7 +35,7 @@ class Utilities:
         validate_sec_params(sec_params)
         # validate_partner_param throws an error if job_type is empty/not provided,
         # but it's not required by get_job_status
-        Utilities.validate_partner_params({**partner_params, "job_type": partner_params.get("job_type", "job_type")})
+        Utilities.validate_partner_params({**partner_params, "job_type": partner_params.get("job_type", 1)})
         if not option_params or option_params is None:
             options = {
                 "return_job_status": True,
